@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -69,9 +69,6 @@ QIcon ShareServiceUrlManagerPrivate::typeToIcon(ShareServiceUrlManager::ServiceT
     case ShareServiceUrlManager::Twitter:
         icon = QIcon::fromTheme(QStringLiteral("im-twitter"));
         break;
-    case ShareServiceUrlManager::GooglePlus:
-        icon = QIcon::fromTheme(QStringLiteral("im-google"));
-        break;
     case ShareServiceUrlManager::MailTo:
         icon = QIcon::fromTheme(QStringLiteral("kmail"));
         break;
@@ -101,9 +98,6 @@ QString ShareServiceUrlManagerPrivate::typeToI18n(ShareServiceUrlManager::Servic
     case ShareServiceUrlManager::Twitter:
         str = i18n("Twitter");
         break;
-    case ShareServiceUrlManager::GooglePlus:
-        str = i18n("Google Plus");
-        break;
     case ShareServiceUrlManager::MailTo:
         str = i18n("Mail");
         break;
@@ -176,14 +170,6 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
         url.setQuery(urlQuery);
         break;
     }
-    case GooglePlus:
-    {
-        url.setUrl(QStringLiteral("https://plus.google.com/share"));
-        QUrlQuery urlQuery;
-        urlQuery.addQueryItem(QStringLiteral("url"), link);
-        url.setQuery(urlQuery);
-        break;
-    }
     case MailTo:
     {
         url.setUrl(QStringLiteral("mailto:"));
