@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 #include "templatemanager.h"
 #include "templatewidgets/templatelistwidget.h"
+#include "pimcommon_debug.h"
 
 #include <KDirWatch>
 
@@ -119,3 +120,8 @@ TemplateInfo TemplateManager::loadTemplate(const QString &themePath, const QStri
     }
     return info;
 }
+
+void TemplateInfo::debug() const
+{
+    qCDebug(PIMCOMMON_LOG) << " name :" << name << " script :" << script;
+}
